<?php
    /**
     * @var View         $this
     * @var string       $content
     * @var SeoComponent $seo
     * @var User         $user
     */
    use artbox\core\components\SeoComponent;
    use artbox\core\models\Feedback;
    use artbox\core\models\Image;
    use artbox\core\models\Page;
    use artbox\core\models\User;
    use artbox\order\models\LoginForm;
    use common\models\Newsletter;
    use common\models\SearchForm;
    use common\models\Settings;
    use frontend\assets\AppAsset;
    use frontend\widgets\LangLink;
    use nodge\eauth\Widget;
    use yii\base\Model;
    use yii\bootstrap\ActiveForm;
    use yii\bootstrap\Html;
    use yii\helpers\Url;
    use yii\web\View;
    use yii\widgets\Breadcrumbs;
    
    AppAsset::register($this);
    /**
     * @var \artbox\order\models\Customer $user
     */
    $user = \Yii::$app->user->identity;
    $seo = Yii::$app->get('seo');
    $feedback = new Feedback();
    $settings = Settings::getInstance();
    $controller = Yii::$app->controller;
    $default_controller = Yii::$app->defaultRoute;
    /**
     * @var LoginForm $loginForm
     */
    $loginForm = \Yii::createObject(
        [
            'class'     => LoginForm::className(),
            'returnUrl' => \Yii::$app->request->absoluteUrl,
        ]
    );
    /**
     * @var Newsletter $newsletter
     */
    $newsletter = \Yii::createObject(
        [
            'class' => Newsletter::className(),
        ]
    );
    $isHome = ( ( $controller->id === $default_controller ) && ( $controller->action->id === $controller->defaultAction ) ) ? true : false;
    /**
     * @var Page[] $pages
     */
    $pages = Page::find()
                 ->where([ 'in_menu' => true ])
                 ->with('lang.alias')
                 ->orderBy(
                     [
                         'sort' => SORT_ASC,
                         'id'   => SORT_ASC,
                     ]
                 )
                 ->all();
    $logo = null;
    if ($settings->logo) {
        $logo_img = Image::findOne($settings->logo);
        if ($logo_img) {
            $logo = $logo_img->getUrl() ?? $logo;
        }
    }
    
    $this->registerMetaTag(
        [
            'name'    => 'description',
            'content' => $seo->desc,
        ]
    );
    
    $js = <<< JS
 //первый слайдер
              $(".slider-first").owlCarousel({
                  responsiveClass: true,
                  navSpeed:150,
                  dots:true,
                  nav:false,
                  items:1
              });

              //бренды
              $(".slider-brands").owlCarousel({
                  responsiveClass: true,
                  responsive: {
                      0: {
                          items: 2,
                          slideBy: 1
                      },

                      370: {
                          items: 3,
                          slideBy: 1
                      },
                      500: {
                          items: 4,
                          slideBy: 1
                      },

                      660: {
                          items: 5,
                          slideBy: 1
                      },

                      768: {
                          items: 6,
                          slideBy: 1
                      },


                      920: {
                          items: 7,
                          slideBy: 1
                      },

                      1200: {
                          items: 9,
                          slideBy: 1
                      }
                  },
                  navSpeed:150,
                  nav:false,
                  dots:false
              })


              //товары + новости
              var owlArticles = $(".slider-articles, .slider-hit, .slider-sales, .slider-exclusive, .slider-news");
              owlArticles.owlCarousel({
                  //            loop:true,
                  responsiveClass: true,
                  responsive: {
                      0: {
                          items: 1,
                          slideBy: 1
                      },

                      370: {
                          items: 1,
                          slideBy: 1
                      },
                      570: {
                          items: 2,
                          slideBy: 1
                      },


                      768: {
                          items: 3,
                          slideBy: 1
                      }
                  },
                  //            navSpeed:150,
                  smartSpeed:150,
                  nav:false,
                  dots:false,
                  onInitialized: function(){
                      owlArticles.next().addClass('vis_ lock');
                      owlArticles.next().next().addClass('vis_');
                  }
              })

              $(".btn-r_ ").click(function(){
                  if(!($(this).hasClass('lock'))){
                      $(this).parent().find(owlArticles).trigger('next.owl.carousel');
                      $(this).parent().parent().addClass('substrate')
                  }

              })

              $(".btn-l_ ").click(function() {
                  if(!($(this).hasClass('lock'))){
                      $(this).parent().find(owlArticles).trigger('prev.owl.carousel');
                      $(this).parent().parent().addClass('substrate')
                  }
              })
              owlArticles.on('changed.owl.carousel', function(event) {

                  var index = event.item.index;
                  var count = event.item.count;
                  var size = event.page.size;
                  if(index==(count-size)){
                      $(this).parent().find(".btn-r_ ").addClass('lock')
                      $(this).parent().parent().addClass('substrate').removeClass('substrate')
                  } else {
                      $(this).parent().find(".btn-r_ ").removeClass('lock')
                  }
                  if (index==0){
                      $(this).parent().find(".btn-l_ ").addClass('lock')
                  } else  {
                      $(this).parent().find(".btn-l_ ").removeClass('lock')
                      $(this).parent().parent().addClass('substrate').removeClass('substrate')
                  }
              })

              owlArticles.on('translated.owl.carousel', function(event) {
                  $(this).parent().parent().removeClass('substrate')

              })

JS;

    $this->registerJs($js, View::POS_READY);
?>

<?php $this->beginPage() ?>
  
  <!DOCTYPE html>
  <html lang="<?= \Yii::$app->language ?>">
    <head>
      <meta charset="<?= \Yii::$app->charset ?>">
      <meta name="viewport" content="width=device-width">
        <?= Html::csrfMetaTags() ?>
      <title><?= Html::encode($seo->title) ?></title>
        <?php $this->head() ?>
      
      <link type="image/x-icon" href="/favicon.ico" rel="icon">

<!--      only with map from google-->
      <script type="text/javascript" src="http://maps.google.com/maps/api/js?sensor=false&key=AIzaSyA_GR59jXZSBeHis3s18AusortelH1flaw"></script>
      <script type="text/javascript" src="../js/markerclusterer.js"></script>

      
      
    </head>
    <body>
        <?php $this->beginBody() ?>
      <!-- Google Analytics -->
      <script>
          (function(i, s, o, g, r, a, m) {
              i[ 'GoogleAnalyticsObject' ] = r;
              i[ r ] = i[ r ] || function() {
                      (i[ r ].q = i[ r ].q || []).push(arguments)
                  }, i[ r ].l = 1 * new Date();
              a = s.createElement(o), m = s.getElementsByTagName(o)[ 0 ];
              a.async = 1;
              a.src = g;
              m.parentNode.insertBefore(a, m)
          })(window, document, 'script', 'https://www.google-analytics.com/analytics.js', 'ga');

          ga('create', <?=$settings->ga_code?>, 'auto');
          ga('send', 'pageview');
      
      </script>
      <div id="all">
          <!-- *** TOP ***
_________________________________________________________ -->
        <div id="header_" class="section-box-header">
          <div class="header-box section-box">
            <div class="container">
              <div class="row">
                <div class="col-xs-6 col-sm-3 col-md-2 col-lg-3 padding-r-none-1200">
                  <div class="height_99">
                    <div class="logo-wr style">
                      <a href="/"><img src="images/logo.png" alt=""></a>
                      <span class="hidden-xs">официальный дистрибьютор Philips, <br />Elstead Lighting в Украине</span>
                    </div>
                    <div class="cities-wr">
                      <div class="cities-tile">
                        <i class="hidden-xs">Вы находитесь</i>
                        <span class="addCity">
                                <i>Киев</i>
                                <div class="hidden_shops">
                                    <ul>
                                        <li class="active">
                                            <span class="s_">Киев</span>
                                            <div class="phones_content">
                                                <p>(068) 776-60-67</p>
                                                <p>(095) 282-85-08</p>
                                                <p>(044) 339-92-33</p>
                                            </div>
                                        </li>
                                        <li>
                                            <span class="s_">Харьков</span>
                                            <div class="phones_content">
                                                <p>(057) 340-58-88</p>
                                            </div>
                                        </li>
                                    </ul>
                                </div>
                            </span>
                      </div>
                    </div>
                  </div>
                </div>
                <div class="col-xs-6 col-sm-9 col-md-7 col-lg-6" style="display: table;">
                  <div class="style header-phones">
                    <p>(068) 776-60-67</p>
                    <p>(095) 282-85-08</p>
                    <p>(044) 339-92-33</p>
              
                    <span class="modal-link modal-callback hidden-xs" data-form="callback">перезвонить мне</span>
                  </div>
                  <div class="style search-header-wr">
                    <div style="display: none;" class="close_search"></div>
                    <form action="">
                      <input type="text" placeholder="введите артикул или ID товара">
                      <button type="submit"></button>
                    </form>
                    <div class="style popular-requests">
                      <p>Популярные запросы</p>
                      <a href="#">Люстры</a>
                      <a href="#">Торшеры</a>
                      <a href="#">Massive</a>
                      <a href="#">Hinkley</a>
                      <a href="#">Настольные лампы</a>
                    </div>
                  </div>
                </div>
                <div class="hidden-xs hidden-sm col-md-1 col-lg-1" style="padding: 0;">
                  <div class="height_99 style header-btns-wr">
                    <div class="style">
                      <!--если товар в избранном или в сравнении добавлять класс "in_active"-->
                      <a class="in_active list_wish" href="#">
                                <span>
                                    <i>25</i>
                                </span>
                        <div>избранное</div>
                      </a>
                    </div>
                    <div class="style">
                      <!--если товар в избранном или в сравнении добавлять класс "in_active"-->
                      <a class="list_compare" href="#">
                                <span>
                                    <!--<i>999</i>-->
                                </span>
                        <div>сравнить</div>
                      </a>
                    </div>
                  </div>
                </div>
                <div class="hidden-xs hidden-sm col-md-2 col-lg-2">
                  <div class="style login-wr">
                    <!--если залогиненный поменять класс login_link на "is_logged" и добавить title="email пользователя"-->
                    <a class="modal-link login_link" data-form="login_modal" href="/ru/site/login" rel="nofollow">
                      <div></div>
                      <span class="">Личный кабинет</span>
                    </a>
              
                    <!--пример-->
                    <!--<a class="is_logged" href="/ru/cabinet/main" title="admin@admin.net">-->
                    <!--<img src="images/ico-all/icologin.png" width="14" height="16" alt="" title="Личный кабинет">-->
                    <!--<span class="">admin@admin.net</span>-->
                    <!--</a>-->
                  </div>
            
                  <a href="basket.html" class="header-basket-wr">
                    <table cellpadding="0" cellspacing="0" border="0">
                      <tr>
                        <td align="center">
                          <span class="header-basket-ico"></span>
                        </td>
                        <td>
                          <!--если пустая то по нулям(0грн,0 товаров) -->
                          <div class="price-header-basket">0<span> грн.</span></div>
                          <div class="proucts-num-header-basket">0 товаров</div>
                        </td>
                      </tr>
                    </table>
                  </a>
                </div>
              </div>
            </div>
          </div>
          <div class="section-box-menu">
            <div class="container">
              <div class="row">
                <div class="hidden-xs hidden-sm col-md-3 catalog-link">
                  <!--если страница не главная добавить для span класс "arrow-catalog" -->
                  <span>Каталог<i></i></span>
                </div>
                <div class="hidden-xs hidden-sm col-md-9 menu-second">
                  <ul>
                    <li class="sail-menu">
                      <a href="#">Распродажа</a>
                      <ul>
                        <li><a href="#">Скидка -25%</a></li>
                        <li><a href="#">Скидка -30%</a></li>
                        <li><a href="#">Скидка -35%</a></li>
                        <li><a href="#">Скидка -40%</a></li>
                        <li><a href="#">Скидка -45%</a></li>
                        <li><a href="#">Скидка -50%</a></li>
                        <li><a href="#">Скидка -55%</a></li>
                        <li><a href="#">Скидка -60%</a></li>
                        <li><a href="#">Скидка -65%</a></li>
                        <li><a href="#">Скидка -70%</a></li>
                        <li><a href="#">Скидка -75%</a></li>
                        <li><a href="#">Скидка -80%</a></li>
                      </ul>
                    </li>
                    <li><a href="#">Гарантии</a></li>
                    <li><a href="#">Оплата</a></li>
                    <li><a href="#">Доставка</a></li>
                    <li><a href="#">Акции</a></li>
                    <li><a href="#">Дисконтная программа</a></li>
                    <li><a href="#">Статьи</a></li>
                  </ul>
                </div>
          
                <div style="display: none;" class="visible-xs visible-sm col-xs-12">
                  <div class="row">
                    <div class="col-xs-2">
                      <div class="menu_mob">
                        <div></div>
                        <div></div>
                      </div>
                      <div id="menu-mob-hidden">
                        <div class="style close-menu-mob">
                          Меню
                          <div class="close_mob"></div>
                        </div>
                        <ul>
                          <li class="bg-mob-menu">
                            <a href="#">Каталог</a>
                            <ul>
                              <li>
                                <a href="#">Лампочки</a>
                              </li>
                              <li>
                                <a href="#">Абажуры и плафоны</a>
                              </li>
                              <li>
                                <a href="#">Точечные светильники</a>
                              </li>
                              <li>
                                <a href="#">Настольные лампы</a>
                              </li>
                              <li>
                                <a href="#">Люстры и потолочные светильники</a>
                              </li>
                              <li>
                                <a href="#">Светильники для ванных комнат</a>
                              </li>
                              <li>
                                <a href="#">Детские светильники</a>
                              </li>
                              <li>
                                <a href="#">Светильники гаджеты</a>
                              </li>
                              <li>
                                <a href="#">Уличные светильники</a>
                              </li>
                              <li>
                                <a href="#">Бра и настенные светильники</a>
                              </li>
                              <li>
                                <a href="#">Торшеры</a>
                              </li>
                              <li>
                                <a href="#">Аксессуары</a>
                              </li>
                            </ul>
                          </li>
                          <li><a href="#">Главная</a></li>
                          <li>
                            <a href="#">Распродажа</a>
                            <ul>
                              <li><a href="#">Скидка -25%</a></li>
                              <li><a href="#">Скидка -30%</a></li>
                              <li><a href="#">Скидка -35%</a></li>
                              <li><a href="#">Скидка -40%</a></li>
                              <li><a href="#">Скидка -45%</a></li>
                              <li><a href="#">Скидка -50%</a></li>
                              <li><a href="#">Скидка -55%</a></li>
                              <li><a href="#">Скидка -60%</a></li>
                              <li><a href="#">Скидка -65%</a></li>
                              <li><a href="#">Скидка -70%</a></li>
                              <li><a href="#">Скидка -75%</a></li>
                              <li><a href="#">Скидка -80%</a></li>
                            </ul>
                          </li>
                          <li><a href="#">Гарантии</a></li>
                          <li><a href="#">Оплата</a></li>
                          <li><a href="#">Доставка</a></li>
                          <li><a href="#">Акции</a></li>
                          <li><a href="#">Дисконтная программа</a></li>
                          <li><a href="#">Статьи</a></li>
                          <li><a href="#">Избранное</a></li>
                          <li><a href="#">Сравнить</a></li>
                    
                          <li class="bg-mob-menu"><a href="#"><span class="modal-link" data-form="callback">перезвонить мне</span></a></li>
                        </ul>
                      </div>
                    </div>
                    <div class="col-xs-10">
                      <div class="style btn-menu-mob">
                        <a class="basket-btn-menu-mob" href="#"><span></span></a>
                        <a class="login-btn-menu-mob" href="#"><span></span></a>
                        <a class="search-btn-menu-mob" href="#"><span></span></a>
                      </div>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </div>
  
        </div>
          
<!--          !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!-->
          <?= $content ?>
<!--        !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!-->
        
        <!-- *** FOOTER ***
_________________________________________________________ -->
          <div id="footer_" class="section-box-footer">
            <div class="section-box-footer-menu-wr">
              <div class="container">
                <div class="row">
                  <div class="col-xs-12 col-sm-3 col-md-3 col-lg-3">
                    <div class="style phones-footer">
                      <p>(068) 776-60-67</p>
                      <p>(095) 282-85-08</p>
                      <p>(044) 339-92-33</p>
                      <span class="modal-link modal-callback" data-form="callback">перезвонить мне</span>
                    </div>
                    <div class="style menu-footer">
                      <ul>
                        <li><a href="#">Распродажа</a></li>
                        <li><a href="#">Гарантии</a></li>
                        <li><a href="#">Оплата</a></li>
                        <li><a href="#">Доставка</a></li>
                        <li><a href="#">Акции</a></li>
                        <li><a href="#">Дисконтная программа</a></li>
                        <li><a href="#">Статьи</a></li>
                      </ul>
              
                      <div style="display: none;" class="visible-xs hidden style hidden_copyright">
                        © 2010-2017 «Лiнiя свiтла»
                      </div>
                    </div>
                  </div>
                  <div class="hidden-xs col-sm-6 col-md-6 col-lg-6">
                    <div class="style search-footer-wr">
                      <form action="">
                        <input type="text" placeholder="введите артикул или ID товара">
                        <button type="submit"></button>
                      </form>
                      <div class="style popular-requests">
                        <p>Популярные запросы</p>
                        <span>Люстры</span>
                        <span>Торшеры</span>
                        <span>Massive</span>
                        <span>Hinkley</span>
                        <span>Настольные лампы</span>
                      </div>
                    </div>
                    <div class="style menu-search-block">
                      <ul>
                        <li><a href="#">Лампочки</a></li>
                        <li><a href="#">Абажуры и плафоны</a></li>
                        <li><a href="#">Точечные светильники</a></li>
                        <li><a href="#">Настольные лампы</a></li>
                        <li><a href="#">Люстры и потолочные светильники</a></li>
                        <li><a href="#">Светильники для ванных комнат</a></li>
                
                        <li><a href="#">Детские светильники</a></li>
                        <li><a href="#">Детские светильники</a></li>
                        <li><a href="#">Уличные светильники</a></li>
                        <li><a href="#">Уличные светильники</a></li>
                        <li><a href="#">Торшеры</a></li>
                        <li><a href="#">Аксессуары</a></li>
                      </ul>
                    </div>
                  </div>
                  <div class="hidden-xs col-sm-3 col-md-3 col-lg-3">
                    <div class="style seti-wrapper">
                      <p class="title_seti">Интернет-магазин в соцсетях</p>
                      <p class="join-seti">Присоединяйтесь к интернет-магазину Лiнiя Свiтла в социальных сетях. Вы всегда будете в курсе акций, распродаж и новинок.</p>
                      <div class="style">
                        <a target="_blank" class="seti-link fb" href="https://www.facebook.com/linija.svitla"></a>
                
                        <a target="_blank" class="seti-link tw" href="#"></a>
                        <a target="_blank" class="seti-link you" href="https://www.youtube.com/channel/UCeM3O8D-aMuftG1FPeIqwJg"></a>
                        <a target="_blank" class="seti-link gpluse" href="https://plus.google.com/101559938155454540015/posts"></a>
                      </div>
                    </div>
                  </div>
                </div>
              </div>
            </div>
            <div class="section-box-copyright">
              <div class="container">
                <div class="row">
                  <div class="hidden-xs col-sm-9">
                    <div class="style copyright-txt">© 2010-2017 «Лiнiя свiтла» - интернет магазин продажи светильников, ламп, бра, торшеров и других осветительных систем. </div>
                  </div>
                  <div class="col-xs-12 col-sm-3">
                    <a class="artweb-link" target="_blank" href="http://artweb.ua/">Создание сайтов</a>
                  </div>
                </div>
              </div>
            </div>
            <div style="display: none" class="btn_up"></div>
            <div style="display: none" class="btn_call">
              <div></div>
            </div>
          </div>
        <!-- *** FOOTER END *** -->
  
        <!--     Modal windows     -->
  
          <div class="call-mobile-wr" style="display: none;">
            <!--<div class="button-call-mob">-->
            <!--<div class="callback-footer modal-link" data-form="callback"><span></span>Обратный звонок</div>-->
            <!--</div>-->
            <div class="call-mobile">
              <div class="button-call-mob">
                <a class="button-call_" href="tel:044 303-90-10">
                  <p>Позвонить</p>
                  <div><span><img src="/images/ico-call/ico-2.png" width="16" height="16"></span></div>
                  <span>044 339-92-33</span>
                </a>
              </div>
      
              <div class="button-call-mob">
                <a class="button-call_" href="tel:050 382-03-00">
                  <p>Позвонить</p>
                  <div><span><img src="/images/ico-call/ico-3.png" width="16" height="16"></span></div>
                  <span>050 282-85-08</span>
                </a>
              </div>
              <!--new_phone-->
              <div class="button-call-mob">
                <a class="button-call_" href="tel:067 385-10-55">
                  <p>Позвонить</p>
                  <div><span><img src="/images/ico-call/ico-4.png" width="16" height="16"></span></div>
                  <span>067 776-60-67</span>
                </a>
              </div>
              <div class="button-call-mob"><a class="call-sms" href="sms:050 282-85-08">Отправить SMS</a>
              </div>
              <div class="button-call-mob">
                <a class="call-contact" href="contacts/linija-svitla.vcf">Добавить в контакты</a>        </div>
            </div>
          </div>
  
          <div id="overlay" style="display: none;"></div>
          <div id="callback" class="forms_" style="display: none;">
            <span id="modal_close"></span>
            <div class="style form-title">Обратный звонок</div>
            <form action="">
              <div class="input-wr">
                <label for="inp-11">Имя</label>
                <input id="inp-11" type="text">
              </div>
              <div class="input-wr phones_mask">
                <label for="inp-22">Телефон</label>
                <input id="inp-22" type="text" placeholder="+38(000)000-00-00">
              </div>
              <div class="input-wr">
                <label for="inp-33">Сообщение</label>
                <textarea id="inp-33" name="" cols="30" rows="10"></textarea>
              </div>
              <div class="button-wr">
                <button type="submit">отправить</button>
              </div>
            </form>
          </div>
          <div id="success_form" style="display: none;">
            <span id="modal_close"></span>
            <div class="txt-success"><span>Спасибо за Ваш запрос!</span><p>Мы свяжемся с вами в ближайшее время.</p></div>
          </div>
  
          <div id="basket_modal" class="basket_modal" style="display: none;">
            <!--basket-modal.html-->
          </div>
  
          <div id="login_modal" class="forms_" style="display: none;">
            <span id="modal_close"></span>
            <div class="login-wrapper">
              <div class="col-xs-12 col-sm-6 col-md-6">
                <form action="#">
                  <form id="w2" action="" method="post">
            
                    <div class="row">
                      <div class="col-xs-12 col-sm-12 input-wr medium-label">
                        <div class="form-group field-loginform-email required">
                          <label class="control-label">Email</label>
                          <input type="text"  autofocus="">
                        </div>
                      </div>
                    </div>
            
                    <div class="row">
                      <div class="col-xs-12 col-sm-12 col-md-12 input-wr medium-label">
                        <div class="form-group field-loginform-password required">
                          <label class="control-label">Пароль</label>
                          <input type="password">
                        </div>
                      </div>
                    </div>
            
                    <div class="row">
                      <div class="col-xs-12 col-sm-12 input-wr sidebar_checks">
                        <div class="form-group field-loginform-rememberme">
                          <input type="checkbox" id="loginform-rememberme" name="LoginForm[rememberMe]" value="1" checked="">
                          <label class="control-label" for="loginform-rememberme"><a>Запомнить меня</a></label>
                        </div>
                      </div>
            
                    </div>
            
                    <div class="row">
                      <div class="col-xs-12 col-sm-12 button-wr">
                        <button type="submit">Войти</button>
                      </div>
                    </div>
                  </form>
                </form>
              </div>
              <div class="col-xs-12 col-sm-6 col-md-6">
                <div class="btns_reg">
                  <a class="restore_password_" href="restore.html">Восстановить пароль</a>
                  <span class="no_account_yet">Нет учетной записи?</span>
                  <a class="to-register-link" href="register.html">Зарегистрироваться</a>
                </div>
              </div>
            </div>
          </div>
          
        <!--     Modal windows     -->

      </div>
      <!-- /#all -->
  
  
      <!--выводить на страницах где есть карта(Главная)-->
      <!--      only with map from google-->
      <script type="text/javascript">
          window.onload = function () {
              initialize()
          }
          function initialize() {
              var start_position  = new google.maps.LatLng('50.435', '30.60');
              var styles = [{
                  stylers: [
                      { saturation: -100 }
                  ]
              }];
              var settings = {
                  styles: styles,
                  zoom: 12,
                  scrollwheel: false,
                  center: start_position,
                  mapTypeControl: true,
                  mapTypeControlOptions: {style: google.maps.MapTypeControlStyle.DROPDOWN_MENU},
                  navigationControl: false,
                  navigationControlOptions: {style: google.maps.NavigationControlStyle.SMALL},
                  scaleControl: true,
                  streetViewControl: true,
                  rotateControl: true,
                  zoomControl: true,
                  mapTypeId: google.maps.MapTypeId.ROADMAP
              };
              var map = new google.maps.Map(document.getElementById("map_canvas"), settings);


              var image1 = new google.maps.MarkerImage('/images/markers/marker-we-1.png',
                  new google.maps.Size(34, 48),
                  new google.maps.Point(0,0),
                  new google.maps.Point(16, 35)
              );



              var markers = [];

              $('.adress-map span').each(function () {
                  var newLat = $(this).data('lat');
                  var newLng = $(this).data('lng');

                  var newName =  $(this).text();


                  var marker = new google.maps.Marker({
                      position: new google.maps.LatLng(newLat, newLng),
                      map: map,
                      title: newName,
                      icon: image1
                  });
                  markers.push(marker);
              })

              var clusterStyles = [
                  {
                      url: '/images/markers/clasters.png',
                      height: 36,
                      width: 36
                  }

              ];
              markerClusterer = new MarkerClusterer(map, markers,
                  {
                      maxZoom: 10,
                      gridSize: 100,
                      styles: clusterStyles
                  });
          }
      </script>
      
        <?php $this->endBody() ?>
    </body>
  </html>
<?php $this->endPage() ?>